#
# spec file for package git-remote-gcrypt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-remote-gcrypt
Version:        1.5
Release:        1.6
Summary:        Encrypted git repositories
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://spwhitton.name/tech/code/git-remote-gcrypt/
Source:         https://github.com/spwhitton/%{name}/archive/%{version}.tar.gz
BuildRequires:  python3-docutils
Requires:       curl
Requires:       git
Requires:       gpg2
Requires:       rsync
BuildArch:      noarch
Suggests:       rclone

%description
This lets git store git repositories in encrypted form.
It supports storing repositories on rsync or sftp servers.
It can also store the encrypted git repository inside a remote git
repository. All the regular git commands like git push and git pull
can be used to operate on such an encrypted repository.

The aim is to provide confidential, authenticated git storage and
collaboration using typical untrusted file hosts or services.

%prep
%setup -q

%build

%install
prefix=%{buildroot}%{_prefix} ./install.sh

%files
%license COPYING
%doc debian/changelog README.rst
%{_bindir}/git-remote-gcrypt
%{_mandir}/man1/git-remote-gcrypt.1%{ext_man}

%changelog
* Mon Aug 22 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5:
  * Pass --error-on-no-transfer to 'rclone copyto'.
  * README.md:
  - explain why the arbitrary <giturl> and sftp:// backends are
    inappropriate for most git repositories
  - use stronger language to say that one should use local or rsync://
    instead, and also say it up in "Description".
* Fri Jan 22 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4:
  * Add gcrypt.require-explicit-force-push configuration key.
  * Support rsync URIs like "rsync://user@host/path" (Closes: #980397).
* Mon Feb 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3:
  * README.md: Clarify how to use GCRYPT_FULL_REPACK.
  * Updates to redhat/git-remote-gcrypt.spec.
  * install.sh: try rst2man.py if rst2man binary not available.
  * Add git-config option to set rsync put flags.
* Tue Nov 27 2018 mvetter@suse.com
- Update to 1.2:
  * When the repository cannot be found, but the repo ID is set,
    output the stderr of other commands to help the user figure out
  what's wrong (Closes: #914059).
  * Note that git-remote-gcrypt's "not found" error can be misleading.
* Sun Apr 29 2018 mvetter@suse.com
- Update to 1.1:
  * Add CONTRIBUTING.md and DEVELOPER-CERTIFICATE.
  * Add experimental rclone backend (for early adoptors only).
* Sat Mar 10 2018 mvetter@suse.com
- Update to 1.0.3:
  * Add note about non-standard rsync:// URI format.
  * Improve first section of manpage.
  * Add "Known issues" to README.
* Sat Sep  2 2017 mvetter@suse.com
- Update to 1.0.2:
  Bug fixes:
  * Correctly handle the case where gcrypt.gpg-args contains more than one
    argument, separated by spaces.
    Thanks Etienne Brodu for the patch.
  Documentation:
  * Drop section "Note to users of GnuPG version 2".
    The issue was a regression in GnuPG 2.x, fixed in version 2.1.16.
  * Add a note about performance when not using the rsync:// or local backends.
  * Add section containing author and maintainer information.
  * Add `apt-get` installation instructions, for the benefit of GitHub users.
  * Other minor edits and formatting changes.
* Thu Mar 16 2017 mvetter@suse.com
- Install real changelog file and not a link
* Thu Mar 16 2017 mvetter@suse.com
- Update to 1.0.1:
  * Add authorship details to script header
- Get proper release tarball from GH now. Before used commit id
  30b3f5e3356bba404eb630807879b8d4989f8c6e which was tag 1.0.0
  on private repo of maintainer
- Use rst2man to generate manpage, install that instead of readme
* Thu Sep 22 2016 mvetter@suse.com
- Use website of new maintainer
* Wed Sep 21 2016 mvetter@suse.com
- Initial package for 1.0.0
